package net.knarcraft.ffmpegconverter.utility;

import org.junit.BeforeClass;
import org.junit.Test;

import java.util.ArrayList;
import java.util.List;

import static junit.framework.TestCase.assertEquals;
import static junit.framework.TestCase.assertTrue;
import static org.junit.Assert.assertArrayEquals;
import static org.junit.Assert.assertFalse;

public class ListUtilTest {
    private static List<Integer> matchesList;
    private static List<Integer> containsList;

    @BeforeClass
    public static void setUp() {
        matchesList = new ArrayList<>();
        matchesList.add(5);
        matchesList.add(7);
        matchesList.add(9);
        matchesList.add(11);
        matchesList.add(13);
        matchesList.add(15);
        matchesList.add(17);
        matchesList.add(19);
        matchesList.add(21);
        matchesList.add(23);
        containsList = List.of(1, 3, 5, 7, 234, 23, 45);
    }

    @Test
    public void concatenate() {
        Integer[] list1 = new Integer[]{5, 2, 34, 56, 12, 78, 43, 4, 2, 43};
        Integer[] list2 = new Integer[]{7, 5, 2, 35, 234, 6, 1, 23, 76, 45, 4};
        Integer[] expected = new Integer[]{5, 2, 34, 56, 12, 78, 43, 4, 2, 43, 7, 5, 2, 35, 234, 6, 1, 23, 76, 45, 4};
        Integer[] result = ListUtil.concatenate(list1, list2);
        assertArrayEquals(expected, result);
    }

    @Test
    public void getMatchingNoMatches() {
        List<Integer> result = ListUtil.getMatching(matchesList, (item) -> item % 2 == 0);
        assertEquals(new ArrayList<>(), result);
    }

    @Test
    public void getMatchingAllMatches() {
        List<Integer> result = ListUtil.getMatching(matchesList, (item) -> item % 2 != 0);
        assertEquals(matchesList, result);
    }

    @Test
    public void getMatchingSomeMatches() {
        List<Integer> result = ListUtil.getMatching(matchesList, (item) -> item < 10);
        List<Integer> expected = new ArrayList<>();
        expected.add(5);
        expected.add(7);
        expected.add(9);
        assertEquals(expected, result);
    }

    @Test
    public void listContainsFalse() {
        assertFalse(ListUtil.listContains(containsList, (item) -> item == 0));
    }

    @Test
    public void listContainsTrue() {
        assertTrue(ListUtil.listContains(containsList, (item) -> item == 234));
    }

    @Test
    public void getList() {
        List<String> inputList = new ArrayList<>();
        inputList.add("some test string");
        inputList.add("some,test,string");
        inputList.add("some te,st string");
        String[] result1 = ListUtil.getListFromCommaSeparatedString(inputList.get(0));
        String[] result2 = ListUtil.getListFromCommaSeparatedString(inputList.get(1));
        String[] result3 = ListUtil.getListFromCommaSeparatedString(inputList.get(2));
        assertArrayEquals(new String[]{"some test string"}, result1);
        assertArrayEquals(new String[]{"some", "test", "string"}, result2);
        assertArrayEquals(new String[]{"some te", "st string"}, result3);
    }

}
